# PolicyConfigResourceURLBundle

A PolicyConfigResourceURL bundle contains information about the resources provided by Agilicus, such as the organisation which administers it, from the perspective of the routing layer of the system. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**host_info** | [**ResourceURLHostInfoMap**](ResourceURLHostInfoMap.md) |  | 
**connector_info** | [**ConnectorBaseInfoMap**](ConnectorBaseInfoMap.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


